Export Package VRC : bcSCA 22lp1 
Update compared VRC:   SCAU22pre 
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : No
Library sources    : Yes
Total file size    : 2586597
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
pbcdllfbcttd414                     SCA 22lp1 (with source)
pbcdllfcprao010                     SCA 22lp1 (with source)
pbcdllfcprmp420                     SCA 22lp1 (with source)
pbcdllfcprpd100                     SCA 22lp1 (with source)
pbcdllfcprpd120                     SCA 22lp1 (with source)
pbcdllfcprpd420                     SCA 22lp1 (with source)
pbcdllfecedi001                     SCA 22lp1 (with source)
pbcdllfecedi003                     SCA 22lp1 (with source)
pbcdllfecedi005                     SCA 22lp1 (with source)
pbcdllfecedi011                     SCA 22lp1 (with source)
pbcdllfecedi015                     SCA 22lp1 (with source)
pbcdllfecedi020                     SCA 22lp1 (with source)
pbcdllfecedi028                     SCA 22lp1 (with source)
pbcdllfecedi200                     SCA 22lp1 (with source)
pbcdllfecedi210                     SCA 22lp1 (with source)
pbcdllfecedi213                     SCA 22lp1 (with source)
pbcdllfecedi215                     SCA 22lp1 (with source)
pbcdllfecedi217                     SCA 22lp1 (with source)
pbcdllfecedi218                     SCA 22lp1 (with source)
pbcdllfecedi219                     SCA 22lp1 (with source)
pbcdllfecedi224                     SCA 22lp1 (with source)
pbcdllfecedi226                     SCA 22lp1 (with source)
pbcdllfecedi228                     SCA 22lp1 (with source)
pbcdllfecedi230                     SCA 22lp1 (with source)
pbcdllfecedi232                     SCA 22lp1 (with source)
pbcdllfecedi240                     SCA 22lp1 (with source)
pbcdllfecedi242                     SCA 22lp1 (with source)
pbcdllfecedi247                     SCA 22lp1 (with source)
pbcdllfecedi250                     SCA 22lp1 (with source)
pbcdllfecedi285                     SCA 22lp1 (with source)
pbcdllfecedi291                     SCA 22lp1 (with source)
pbcdllfecedi292                     SCA 22lp1 (with source)
pbcdllfecedi294                     SCA 22lp1 (with source)
pbcdllfecedi295                     SCA 22lp1 (with source)
pbcdllfecedi297                     SCA 22lp1 (with source)
pbcdllfecedi298                     SCA 22lp1 (with source)
pbcdllfecedi299                     SCA 22lp1 (with source)
pbcdllfecedi432                     SCA 22lp1 (with source)
pbcdllfecedi433                     SCA 22lp1 (with source)
pbcdllfecedi500                     SCA 22lp1 (with source)
pbcdllfecedi501                     SCA 22lp1 (with source)
pbcdllfecedi502                     SCA 22lp1 (with source)
pbcdllfecedi505                     SCA 22lp1 (with source)
pbcdllfecedi700                     SCA 22lp1 (with source)
pbcdllfecedi701                     SCA 22lp1 (with source)
pbcdllfecedi708                     SCA 22lp1 (with source)
pbcdllfecedi720                     SCA 22lp1 (with source)
pbcdllfecedi750                     SCA 22lp1 (with source)
pbcdllfecedi751                     SCA 22lp1 (with source)
pbcdllfecedi760                     SCA 22lp1 (with source)
pbcdllfecedi910                     SCA 22lp1 (with source)
pbcdllftccom110                     SCA 22lp1 (with source)
pbcdllftccom111                     SCA 22lp1 (with source)
pbcdllftccom112                     SCA 22lp1 (with source)
pbcdllftccom113                     SCA 22lp1 (with source)
pbcdllftccom114                     SCA 22lp1 (with source)
pbcdllftccom117                     SCA 22lp1 (with source)
pbcdllftccom120                     SCA 22lp1 (with source)
pbcdllftccom121                     SCA 22lp1 (with source)
pbcdllftccom122                     SCA 22lp1 (with source)
pbcdllftccom123                     SCA 22lp1 (with source)
pbcdllftccom126                     SCA 22lp1 (with source)
pbcdllftccom130                     SCA 22lp1 (with source)
pbcdllftccom133                     SCA 22lp1 (with source)
pbcdllftccom136                     SCA 22lp1 (with source)
pbcdllftccom138                     SCA 22lp1 (with source)
pbcdllftccom140                     SCA 22lp1 (with source)
pbcdllftccom145                     SCA 22lp1 (with source)
pbcdllftccom150                     SCA 22lp1 (with source)
pbcdllftccom900                     SCA 22lp1 (with source)
pbcdllftcemm122                     SCA 22lp1 (with source)
pbcdllftcibd001                     SCA 22lp1 (with source)
pbcdllftcibd003                     SCA 22lp1 (with source)
pbcdllftcibd005                     SCA 22lp1 (with source)
pbcdllftcibd006                     SCA 22lp1 (with source)
pbcdllftcibd100                     SCA 22lp1 (with source)
pbcdllftcibd200                     SCA 22lp1 (with source)
pbcdllftcibd401                     SCA 22lp1 (with source)
pbcdllftcibd903                     SCA 22lp1 (with source)
pbcdllftcibd905                     SCA 22lp1 (with source)
pbcdllftcibd906                     SCA 22lp1 (with source)
pbcdllftcmcs096                     SCA 22lp1 (with source)
pbcdllftctax400                     SCA 22lp1 (with source)
pbcdllftdipu001                     SCA 22lp1 (with source)
pbcdllftdipu010                     SCA 22lp1 (with source)
pbcdllftdipu100                     SCA 22lp1 (with source)
pbcdllftdipu901                     SCA 22lp1 (with source)
pbcdllftdisa001                     SCA 22lp1 (with source)
pbcdllftdpur043                     SCA 22lp1 (with source)
pbcdllftdpur300                     SCA 22lp1 (with source)
pbcdllftdpur301                     SCA 22lp1 (with source)
pbcdllftdpur303                     SCA 22lp1 (with source)
pbcdllftdpur306                     SCA 22lp1 (with source)
pbcdllftdpur350                     SCA 22lp1 (with source)
pbcdllftdpur351                     SCA 22lp1 (with source)
pbcdllftdpur353                     SCA 22lp1 (with source)
pbcdllftdpur400                     SCA 22lp1 (with source)
pbcdllftdpur414                     SCA 22lp1 (with source)
pbcdllftdpur900                     SCA 22lp1 (with source)
pbcdllftdpur901                     SCA 22lp1 (with source)
pbcdllftdsls039                     SCA 22lp1 (with source)
pbcdllftdsls906                     SCA 22lp1 (with source)
pbcdllftdsls907                     SCA 22lp1 (with source)
pbcdllftdsls910                     SCA 22lp1 (with source)
pbcdllftfgld901                     SCA 22lp1 (with source)
pbcdllftibom010                     SCA 22lp1 (with source)
pbcdllftibom901                     SCA 22lp1 (with source)
pbcdllftibom902                     SCA 22lp1 (with source)
pbcdllftibom903                     SCA 22lp1 (with source)
pbcdllfticpr007                     SCA 22lp1 (with source)
pbcdllfticpr160                     SCA 22lp1 (with source)
pbcdllfticpr201                     SCA 22lp1 (with source)
pbcdllfticpr205                     SCA 22lp1 (with source)
pbcdllfticpr206                     SCA 22lp1 (with source)
pbcdllfticpr301                     SCA 22lp1 (with source)
pbcdllfticpr305                     SCA 22lp1 (with source)
pbcdllfticpr340                     SCA 22lp1 (with source)
pbcdllftiedm010                     SCA 22lp1 (with source)
pbcdllftiedm100                     SCA 22lp1 (with source)
pbcdllftiedm101                     SCA 22lp1 (with source)
pbcdllftiedm110                     SCA 22lp1 (with source)
pbcdllftiedm980                     SCA 22lp1 (with source)
pbcdllftiedm981                     SCA 22lp1 (with source)
pbcdllftiedm982                     SCA 22lp1 (with source)
pbcdllftiedm990                     SCA 22lp1 (with source)
pbcdllftiedm991                     SCA 22lp1 (with source)
pbcdllftiedm992                     SCA 22lp1 (with source)
pbcdllftiedm993                     SCA 22lp1 (with source)
pbcdllftiedm999                     SCA 22lp1 (with source)
pbcdllftiipd001                     SCA 22lp1 (with source)
pbcdllftirou101                     SCA 22lp1 (with source)
pbcdllftirou102                     SCA 22lp1 (with source)
pbcdllftirou110                     SCA 22lp1 (with source)
pbcdllftirou900                     SCA 22lp1 (with source)
pbcdllftirou902                     SCA 22lp1 (with source)
pbcdllftitrp001                     SCA 22lp1 (with source)
pbcdllftitrp002                     SCA 22lp1 (with source)
pbcdllftitrp005                     SCA 22lp1 (with source)
pbcdllftitrp007                     SCA 22lp1 (with source)
pbcdllftitrp901                     SCA 22lp1 (with source)
pbcdllftitrp902                     SCA 22lp1 (with source)
pbcdllftitrp903                     SCA 22lp1 (with source)
pbcdllftitrp904                     SCA 22lp1 (with source)
pbcdllftitrp906                     SCA 22lp1 (with source)
pbcdllftitrp912                     SCA 22lp1 (with source)
pbcdllftttxt001                     SCA 22lp1 (with source)
pbcdllftttxt002                     SCA 22lp1 (with source)
pbcdllftttxt004                     SCA 22lp1 (with source)
pbcdllftttxt005                     SCA 22lp1 (with source)
pbcdllfwhltc500                     SCA 22lp1 (with source)
pbcdllfwhwmd210                     SCA 22lp1 (with source)
pbcdllfwhwmd300                     SCA 22lp1 (with source)
pbcdllfwhwmd302                     SCA 22lp1 (with source)
pbcdllfwhwmd400                     SCA 22lp1 (with source)
pbcdllmtccom100                     SCA 22lp1 (with source)
pbcdllmtdpur401                     SCA 22lp1 (with source)
pbcdllmticpr300                     SCA 22lp1 (with source)
pbcdllmwhinr140                     SCA 22lp1 (with source)
pbcdllmwhwmd215                     SCA 22lp1 (with source)
obcdllfbcttd414                     SCA 22lp1
obcdllfcprao010                     SCA 22lp1
obcdllfcprmp420                     SCA 22lp1
obcdllfcprpd100                     SCA 22lp1
obcdllfcprpd120                     SCA 22lp1
obcdllfcprpd420                     SCA 22lp1
obcdllfecedi001                     SCA 22lp1
obcdllfecedi003                     SCA 22lp1
obcdllfecedi005                     SCA 22lp1
obcdllfecedi011                     SCA 22lp1
obcdllfecedi015                     SCA 22lp1
obcdllfecedi020                     SCA 22lp1
obcdllfecedi028                     SCA 22lp1
obcdllfecedi200                     SCA 22lp1
obcdllfecedi210                     SCA 22lp1
obcdllfecedi213                     SCA 22lp1
obcdllfecedi215                     SCA 22lp1
obcdllfecedi217                     SCA 22lp1
obcdllfecedi218                     SCA 22lp1
obcdllfecedi219                     SCA 22lp1
obcdllfecedi224                     SCA 22lp1
obcdllfecedi226                     SCA 22lp1
obcdllfecedi228                     SCA 22lp1
obcdllfecedi230                     SCA 22lp1
obcdllfecedi232                     SCA 22lp1
obcdllfecedi240                     SCA 22lp1
obcdllfecedi242                     SCA 22lp1
obcdllfecedi247                     SCA 22lp1
obcdllfecedi250                     SCA 22lp1
obcdllfecedi285                     SCA 22lp1
obcdllfecedi291                     SCA 22lp1
obcdllfecedi292                     SCA 22lp1
obcdllfecedi294                     SCA 22lp1
obcdllfecedi295                     SCA 22lp1
obcdllfecedi297                     SCA 22lp1
obcdllfecedi298                     SCA 22lp1
obcdllfecedi299                     SCA 22lp1
obcdllfecedi432                     SCA 22lp1
obcdllfecedi433                     SCA 22lp1
obcdllfecedi500                     SCA 22lp1
obcdllfecedi501                     SCA 22lp1
obcdllfecedi502                     SCA 22lp1
obcdllfecedi505                     SCA 22lp1
obcdllfecedi700                     SCA 22lp1
obcdllfecedi701                     SCA 22lp1
obcdllfecedi708                     SCA 22lp1
obcdllfecedi720                     SCA 22lp1
obcdllfecedi750                     SCA 22lp1
obcdllfecedi751                     SCA 22lp1
obcdllfecedi760                     SCA 22lp1
obcdllfecedi910                     SCA 22lp1
obcdllftccom110                     SCA 22lp1
obcdllftccom111                     SCA 22lp1
obcdllftccom112                     SCA 22lp1
obcdllftccom113                     SCA 22lp1
obcdllftccom114                     SCA 22lp1
obcdllftccom117                     SCA 22lp1
obcdllftccom120                     SCA 22lp1
obcdllftccom121                     SCA 22lp1
obcdllftccom122                     SCA 22lp1
obcdllftccom123                     SCA 22lp1
obcdllftccom126                     SCA 22lp1
obcdllftccom130                     SCA 22lp1
obcdllftccom133                     SCA 22lp1
obcdllftccom136                     SCA 22lp1
obcdllftccom138                     SCA 22lp1
obcdllftccom140                     SCA 22lp1
obcdllftccom145                     SCA 22lp1
obcdllftccom150                     SCA 22lp1
obcdllftccom900                     SCA 22lp1
obcdllftcemm122                     SCA 22lp1
obcdllftcibd001                     SCA 22lp1
obcdllftcibd003                     SCA 22lp1
obcdllftcibd005                     SCA 22lp1
obcdllftcibd006                     SCA 22lp1
obcdllftcibd100                     SCA 22lp1
obcdllftcibd200                     SCA 22lp1
obcdllftcibd401                     SCA 22lp1
obcdllftcibd903                     SCA 22lp1
obcdllftcibd905                     SCA 22lp1
obcdllftcibd906                     SCA 22lp1
obcdllftcmcs096                     SCA 22lp1
obcdllftctax400                     SCA 22lp1
obcdllftdipu001                     SCA 22lp1
obcdllftdipu010                     SCA 22lp1
obcdllftdipu100                     SCA 22lp1
obcdllftdipu901                     SCA 22lp1
obcdllftdisa001                     SCA 22lp1
obcdllftdpur043                     SCA 22lp1
obcdllftdpur300                     SCA 22lp1
obcdllftdpur301                     SCA 22lp1
obcdllftdpur303                     SCA 22lp1
obcdllftdpur306                     SCA 22lp1
obcdllftdpur350                     SCA 22lp1
obcdllftdpur351                     SCA 22lp1
obcdllftdpur353                     SCA 22lp1
obcdllftdpur400                     SCA 22lp1
obcdllftdpur414                     SCA 22lp1
obcdllftdpur900                     SCA 22lp1
obcdllftdpur901                     SCA 22lp1
obcdllftdsls039                     SCA 22lp1
obcdllftdsls906                     SCA 22lp1
obcdllftdsls907                     SCA 22lp1
obcdllftdsls910                     SCA 22lp1
obcdllftfgld901                     SCA 22lp1
obcdllftibom010                     SCA 22lp1
obcdllftibom901                     SCA 22lp1
obcdllftibom902                     SCA 22lp1
obcdllftibom903                     SCA 22lp1
obcdllfticpr007                     SCA 22lp1
obcdllfticpr160                     SCA 22lp1
obcdllfticpr201                     SCA 22lp1
obcdllfticpr205                     SCA 22lp1
obcdllfticpr206                     SCA 22lp1
obcdllfticpr301                     SCA 22lp1
obcdllfticpr305                     SCA 22lp1
obcdllfticpr340                     SCA 22lp1
obcdllftiedm010                     SCA 22lp1
obcdllftiedm100                     SCA 22lp1
obcdllftiedm101                     SCA 22lp1
obcdllftiedm110                     SCA 22lp1
obcdllftiedm980                     SCA 22lp1
obcdllftiedm981                     SCA 22lp1
obcdllftiedm982                     SCA 22lp1
obcdllftiedm990                     SCA 22lp1
obcdllftiedm991                     SCA 22lp1
obcdllftiedm992                     SCA 22lp1
obcdllftiedm993                     SCA 22lp1
obcdllftiedm999                     SCA 22lp1
obcdllftiipd001                     SCA 22lp1
obcdllftirou101                     SCA 22lp1
obcdllftirou102                     SCA 22lp1
obcdllftirou110                     SCA 22lp1
obcdllftirou900                     SCA 22lp1
obcdllftirou902                     SCA 22lp1
obcdllftitrp001                     SCA 22lp1
obcdllftitrp002                     SCA 22lp1
obcdllftitrp005                     SCA 22lp1
obcdllftitrp007                     SCA 22lp1
obcdllftitrp901                     SCA 22lp1
obcdllftitrp902                     SCA 22lp1
obcdllftitrp903                     SCA 22lp1
obcdllftitrp904                     SCA 22lp1
obcdllftitrp906                     SCA 22lp1
obcdllftitrp912                     SCA 22lp1
obcdllftttxt001                     SCA 22lp1
obcdllftttxt002                     SCA 22lp1
obcdllftttxt004                     SCA 22lp1
obcdllftttxt005                     SCA 22lp1
obcdllfwhltc500                     SCA 22lp1
obcdllfwhwmd210                     SCA 22lp1
obcdllfwhwmd300                     SCA 22lp1
obcdllfwhwmd302                     SCA 22lp1
obcdllfwhwmd400                     SCA 22lp1
obcdllmtccom100                     SCA 22lp1
obcdllmtdpur401                     SCA 22lp1
obcdllmticpr300                     SCA 22lp1
obcdllmwhinr140                     SCA 22lp1
obcdllmwhwmd215                     SCA 22lp1
